@@ -58,7 +58,7 @@ class BindListener:
 
     async def send_bind(self,bind:'Bind'):
         if isinstance(bind.f,str):
-            cmd = f"keyword bind \"{','.join(bind.key) },{bind.f}\""
+            cmd = f"keyword bind{bind.flag} \"{','.join(bind.key) },{bind.f}\""
         else:
             cmd = f"keyword bind{bind.flag} \"{','.join(bind.key) },exec,echo bind.{'.'.join(bind.key)} | socat unix-connect:/tmp/hypr_py/$HYPRLAND_INSTANCE_SIGNATURE/.socket.sock STDIO\""
         await async_hyprctl(cmd)
